@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2016 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2018 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -24,8 +24,7 @@
 #include "messageviewer_export.h"
 class KActionCollection;
 
-namespace MessageViewer
-{
+namespace MessageViewer {
 class ViewerPluginPrivate;
 class ViewerPluginInterface;
 class MESSAGEVIEWER_EXPORT ViewerPlugin : public QObject
@@ -35,13 +34,13 @@ public:
     explicit ViewerPlugin(QObject *parent = nullptr);
     ~ViewerPlugin();
 
-    virtual MessageViewer::ViewerPluginInterface *createView(QWidget *parent, KActionCollection *ac) = 0;
-    virtual QString viewerPluginName() const = 0;
+    Q_REQUIRED_RESULT virtual MessageViewer::ViewerPluginInterface *createView(QWidget *parent, KActionCollection *ac) = 0;
+    Q_REQUIRED_RESULT virtual QString viewerPluginName() const = 0;
     virtual void showConfigureDialog(QWidget *parent = nullptr);
-    virtual bool hasConfigureDialog() const;
+    Q_REQUIRED_RESULT virtual bool hasConfigureDialog() const;
 
     void setIsEnabled(bool enabled);
-    bool isEnabled() const;
+    Q_REQUIRED_RESULT bool isEnabled() const;
 
 Q_SIGNALS:
     void configChanged();
